# -*- coding: utf-8 -*-
"""
Galicia-specific Form helpers
"""

from __future__ import absolute_import, unicode_literals
from django.forms.fields import Select
from .municipalities import MUNICIPALITY_CHOICES
from .comarcas import COMARCA_CHOICES
from .provinces import PROVINCE_CHOICES


class GaliciaMunicipalitySelect(Select):
    """
    A Select widget that uses a list of Galician municipalities as its choices.
    """
    def __init__(self, attrs=None):
        super(GaliciaMunicipalitySelect, self).__init__(attrs, choices=MUNICIPALITY_CHOICES)


class GaliciaComarcaSelect(Select):
    """
    A Select widget that uses a list of Galician comarcas as its choices.
    """
    def __init__(self, attrs=None):
        super(GaliciaComarcaSelect, self).__init__(attrs, choices=COMARCA_CHOICES)


class GaliciaProvinceSelect(Select):
    """
    A Select widget that uses a list of Galician provinces as its choices.
    """
    def __init__(self, attrs=None):
        super(GaliciaProvinceSelect, self).__init__(attrs, choices=PROVINCE_CHOICES)



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

setup(
    name = 'django-galicia',
    version = '0.1',
    description = 'Django helpers for Galicia (Spain).',
    long_description = README,
    author = 'Afonso Fernandez Nogueira',
    author_email = 'fonzzo+django-galicia@gmail.com',
    license='BSD',
    url = 'https://bitbucket.org/fonso/django-galicia',
    packages = ['django_galicia'],
    include_package_data = True,
    classifiers = [
        'Development Status :: 1 - Planning',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    install_requires=[
        'Django>=1.4',
    ]
)
